@@ -33,15 +33,18 @@ from libcloud.utils.py3 import httplib
 from libcloud.utils.py3 import urlparse
 from libcloud.utils.py3 import urlencode
 from libcloud.utils.py3 import StringIO
+from libcloud.utils.py3 import u
 from libcloud.utils.py3 import b
 
 from libcloud.utils.misc import lowercase_keys
+from libcloud.utils.compression import decompress_data
 from libcloud.common.types import LibcloudError, MalformedResponseError
 
 from libcloud.httplib_ssl import LibcloudHTTPSConnection
 
 LibcloudHTTPConnection = httplib.HTTPConnection
 
+
 class Response(object):
     """
     A Base Response class to derive from.
@@ -57,7 +60,7 @@ class Response(object):
     parse_zero_length_body = False
 
     def __init__(self, response, connection):
-        self.body = response.read().strip()
+        self.body = self._decompress_response(response=response)
 
         if PY3:
             self.body = b(self.body).decode('utf-8')
@@ -106,6 +109,31 @@ class Response(object):
         """
         return self.status == httplib.OK or self.status == httplib.CREATED
 
+    def _decompress_response(self, response):
+        """
+        Decompress a response body if it is using deflate or gzip encoding.
+
+        @return: Decompressed response
+        """
+        headers = lowercase_keys(dict(response.getheaders()))
+        encoding = headers.get('content-encoding', None)
+
+        original_data = getattr(response, '_original_data', None)
+
+        if original_data is not None:
+            return original_data
+
+        body = response.read()
+
+        if encoding in  ['zlib', 'deflate']:
+            body = decompress_data('zlib', body)
+        elif encoding in ['gzip', 'x-gzip']:
+            body = decompress_data('gzip', body)
+        else:
+            body = body.strip()
+
+        return body
+
 
 class JsonResponse(Response):
     """
@@ -136,9 +164,9 @@ class XmlResponse(Response):
             return self.body
 
         try:
-          body = ET.XML(self.body)
+            body = ET.XML(self.body)
         except:
-          raise MalformedResponseError("Failed to parse XML",
+            raise MalformedResponseError("Failed to parse XML",
                                        body=self.body,
                                        driver=self.connection.driver)
         return body
@@ -156,7 +184,6 @@ class RawResponse(Response):
         self._reason = None
         self.connection = connection
 
-
     @property
     def response(self):
         if not self._response:
@@ -208,26 +235,46 @@ class LoggingConnection():
         for h in r.getheaders():
             ht += "%s: %s\r\n" % (h[0].title(), h[1])
         ht += "\r\n"
+
         # this is evil. laugh with me. ha arharhrhahahaha
         class fakesock:
             def __init__(self, s):
                 self.s = s
-            def makefile(self, mode, foo):
-                return StringIO(self.s)
+
+            def makefile(self, *args, **kwargs):
+                if PY3:
+                    from io import BytesIO
+                    cls = BytesIO
+                else:
+                    cls = StringIO
+
+                return cls(b(self.s))
         rr = r
+        original_data = body
+        headers = lowercase_keys(dict(r.getheaders()))
+
+        encoding = headers.get('content-encoding', None)
+
+        if encoding in  ['zlib', 'deflate']:
+            body = decompress_data('zlib', body)
+        elif encoding in ['gzip', 'x-gzip']:
+            body = decompress_data('gzip', body)
+
         if r.chunked:
             ht += "%x\r\n" % (len(body))
-            ht += body
+            ht += u(body)
             ht += "\r\n0\r\n"
         else:
-            ht += body
-        rr = httplib.HTTPResponse(fakesock(ht),
+            ht += u(body)
+        rr = httplib.HTTPResponse(sock=fakesock(ht),
                                   method=r._method,
                                   debuglevel=r.debuglevel)
         rr.begin()
         rv += ht
         rv += ("\n# -------- end %d:%d response ----------\n"
                % (id(self), id(r)))
+
+        rr._original_data = body
         return (rr, rv)
 
     def _log_curl(self, method, url, body, headers):
@@ -242,6 +289,8 @@ class LoggingConnection():
         if body is not None and len(body) > 0:
             cmd.extend(["--data-binary", pquote(body)])
 
+        cmd.extend(["--compress"])
+
         cmd.extend([pquote("https://%s:%d%s" % (self.host, self.port, url))])
         return " ".join(cmd)
 
@@ -261,11 +310,12 @@ class LoggingHTTPSConnection(LoggingConnection, LibcloudHTTPSConnection):
     def request(self, method, url, body=None, headers=None):
         headers.update({'X-LC-Request-ID': str(id(self))})
         if self.log is not None:
-            pre = "# -------- begin %d request ----------\n"  % id(self)
+            pre = "# -------- begin %d request ----------\n" % id(self)
             self.log.write(pre +
                            self._log_curl(method, url, body, headers) + "\n")
             self.log.flush()
-        return LibcloudHTTPSConnection.request(self, method, url, body, headers)
+        return LibcloudHTTPSConnection.request(self, method, url, body,
+                                               headers)
 
 class LoggingHTTPConnection(LoggingConnection, LibcloudHTTPConnection):
     """
@@ -283,7 +333,7 @@ class LoggingHTTPConnection(LoggingConnection, LibcloudHTTPConnection):
     def request(self, method, url, body=None, headers=None):
         headers.update({'X-LC-Request-ID': str(id(self))})
         if self.log is not None:
-            pre = "# -------- begin %d request ----------\n"  % id(self)
+            pre = "# -------- begin %d request ----------\n" % id(self)
             self.log.write(pre +
                            self._log_curl(method, url, body, headers) + "\n")
             self.log.flush()
@@ -326,7 +376,8 @@ class Connection(object):
                 self.port = 80
 
         if url:
-            (self.host, self.port, self.secure, self.request_path) = self._tuple_from_url(url)
+            (self.host, self.port, self.secure,
+             self.request_path) = self._tuple_from_url(url)
 
     def set_context(self, context):
         self.context = context
@@ -334,7 +385,8 @@ class Connection(object):
     def _tuple_from_url(self, url):
         secure = 1
         port = None
-        scheme, netloc, request_path, param, query, fragment = urlparse.urlparse(url)
+        (scheme, netloc, request_path, param,
+         query, fragment) = urlparse.urlparse(url)
 
         if scheme not in ['http', 'https']:
             raise LibcloudError('Invalid scheme: %s in url %s' % (scheme, url))
@@ -356,7 +408,7 @@ class Connection(object):
 
         return (host, port, secure, request_path)
 
-    def connect(self, host=None, port=None, base_url = None):
+    def connect(self, host=None, port=None, base_url=None):
         """
         Establish a connection with the API server.
 
@@ -461,6 +513,9 @@ class Connection(object):
         # We always send a user-agent header
         headers.update({'User-Agent': self._user_agent()})
 
+        # Indicate that support gzip and deflate compression
+        headers.update({'Accept-Encoding': 'gzip,deflate'})
+
         p = int(self.port)
 
         if p not in (80, 443):
@@ -511,7 +566,7 @@ class Connection(object):
         return response
 
     def morph_action_hook(self, action):
-        return self.request_path  + action
+        return self.request_path + action
 
     def add_default_params(self, params):
         """
@@ -570,7 +625,7 @@ class PollingConnection(Connection):
         """
         Perform an 'async' request to the specified path. Keep in mind that
         this function is *blocking* and 'async' in this case means that the
-        hit URL only returns a job ID which is the periodically polled until 
+        hit URL only returns a job ID which is the periodically polled until
         the job has completed.
 
         This function works like this:
@@ -614,14 +669,16 @@ class PollingConnection(Connection):
                                          context=context)
         response = request(**kwargs)
         kwargs = self.get_poll_request_kwargs(response=response,
-                                              context=context)
+                                              context=context,
+                                              request_kwargs=kwargs)
 
         end = time.time() + self.timeout
         completed = False
         while time.time() < end and not completed:
             response = request(**kwargs)
             completed = self.has_completed(response=response)
-            time.sleep(self.poll_interval)
+            if not completed:
+                time.sleep(self.poll_interval)
 
         if not completed:
             raise LibcloudError('Job did not complete in %s seconds' %
@@ -639,7 +696,7 @@ class PollingConnection(Connection):
                   'headers': headers, 'method': method}
         return kwargs
 
-    def get_poll_request_kwargs(self, response, context):
+    def get_poll_request_kwargs(self, response, context, request_kwargs):
         """
         Return keyword arguments which are passed to the request() method when
         polling for the job status.
@@ -647,6 +704,10 @@ class PollingConnection(Connection):
         @param response: Response object returned by poll request.
         @type response: C{HTTPResponse}
 
+        @param request_kwargs: Kwargs previously used to initiate the
+                                  poll request.
+        @type response: C{dict}
+
         @return C{dict} Keyword arguments
         """
         raise NotImplementedError('get_poll_request_kwargs not implemented')
