@@ -27,13 +27,15 @@ Linode(R) is a registered trademark of Linode, LLC.
 
 """
 
+import os
+import hashlib
+
 try:
     import simplejson as json
 except ImportError:
     import json
 
 import itertools
-import os
 import binascii
 
 from copy import copy
@@ -229,8 +231,10 @@ class LinodeNodeDriver(NodeDriver):
             raise LinodeException(0xFB, "Root password is too short")
 
         # Swap size
-        try: swap = 128 if "ex_swap" not in kwargs else int(kwargs["ex_swap"])
-        except: raise LinodeException(0xFB, "Need an integer swap size")
+        try:
+            swap = 128 if "ex_swap" not in kwargs else int(kwargs["ex_swap"])
+        except:
+            raise LinodeException(0xFB, "Need an integer swap size")
 
         # Root partition size
         imagesize = (size.disk - swap) if "ex_rsize" not in kwargs else \
@@ -299,7 +303,8 @@ class LinodeNodeDriver(NodeDriver):
 
         # Step 2: linode.disk.createfromdistribution
         if not root:
-            root = u(binascii.hexlifyos.urandom(8).encode('hex'))
+            root = binascii.b2a_base64(os.urandom(8)).decode('ascii')
+
         params = {
             "api_action":       "linode.disk.createfromdistribution",
             "LinodeID":         linode["id"],
@@ -308,7 +313,8 @@ class LinodeNodeDriver(NodeDriver):
             "Size":             imagesize,
             "rootPass":         root,
         }
-        if ssh: params["rootSSHKey"] = ssh
+        if ssh:
+            params["rootSSHKey"] = ssh
         data = self.connection.request(API_ROOT, params=params).objects[0]
         linode["rootimage"] = data["DiskID"]
 
@@ -399,10 +405,14 @@ class LinodeNodeDriver(NodeDriver):
         nl = []
         for dc in data:
             country = None
-            if "USA" in dc["LOCATION"]: country = "US"
-            elif "UK" in dc["LOCATION"]: country = "GB"
-            elif "JP" in dc["LOCATION"]: country = "JP"
-            else: country = "??"
+            if "USA" in dc["LOCATION"]:
+                country = "US"
+            elif "UK" in dc["LOCATION"]:
+                country = "GB"
+            elif "JP" in dc["LOCATION"]:
+                country = "JP"
+            else:
+                country = "??"
             nl.append(NodeLocation(dc["DATACENTERID"],
                                    dc["LOCATION"],
                                    country,
@@ -483,9 +493,11 @@ def _izip_longest(*args, **kwds):
 
     http://docs.python.org/library/itertools.html#itertools.izip
     """
+
     fillvalue = kwds.get('fillvalue')
+
     def sentinel(counter = ([fillvalue]*(len(args)-1)).pop):
-        yield counter() # yields the fillvalue, or raises IndexError
+        yield counter()  # yields the fillvalue, or raises IndexError
     fillers = itertools.repeat(fillvalue)
     iters = [itertools.chain(it, sentinel(), fillers) for it in args]
     try:
