@@ -30,6 +30,7 @@ import warnings
 from libcloud.utils.py3 import httplib
 from libcloud.utils.py3 import b
 from libcloud.utils.py3 import next
+from libcloud.utils.py3 import urlparse
 
 import base64
 
@@ -929,16 +930,13 @@ class OpenStack_1_1_NodeDriver(OpenStackNodeDriver):
         return resp.status == httplib.ACCEPTED
 
     def ex_save_image(self, node, name, metadata=None):
-        # This has not yet been implemented by OpenStack 1.1
-        raise NotImplementedError()
-
         optional_params = {}
         if metadata:
             optional_params['metadata'] = metadata
         resp = self._node_action(node, 'createImage', name=name,
                                  **optional_params)
-        # TODO: concevt location header into NodeImage object
-        return resp.status == httplib.NO_CONTENT
+        image_id = self._extract_image_id_from_url(resp.headers['location'])
+        return self.ex_get_image(image_id=image_id)
 
     def ex_set_server_name(self, node, name):
         """
@@ -994,12 +992,9 @@ class OpenStack_1_1_NodeDriver(OpenStackNodeDriver):
                    .object['image'])
 
     def ex_delete_image(self, image):
-        # This has not yet been implemented by OpenStack 1.1
-        raise NotImplementedError()
-
         resp = self.connection.request('/images/%s' % (image.id,),
                                        method='DELETE')
-        return resp.status == httplib.ACCEPTED
+        return resp.status == httplib.NO_CONTENT
 
     def _node_action(self, node, action, **params):
         params = params or None
@@ -1071,3 +1066,8 @@ class OpenStack_1_1_NodeDriver(OpenStackNodeDriver):
                 )
             except KeyError:
                 return(0.0)
+
+    def _extract_image_id_from_url(self, location_header):
+        path = urlparse.urlparse(location_header).path
+        image_id = path.split('/')[-1]
+        return image_id
