@@ -39,6 +39,8 @@ DRIVERS = {
         ('libcloud.compute.drivers.ec2', 'EC2APSENodeDriver'),
     Provider.EC2_AP_NORTHEAST:
         ('libcloud.compute.drivers.ec2', 'EC2APNENodeDriver'),
+    Provider.EC2_SA_EAST:
+        ('libcloud.compute.drivers.ec2', 'EC2SAEastNodeDriver'),
     Provider.ECP:
         ('libcloud.compute.drivers.ecp', 'ECPNodeDriver'),
     Provider.ELASTICHOSTS_UK1:
