@@ -36,6 +36,7 @@ class Provider(object):
     GOGRID = 1
     NINEFOLD = 2
     RACKSPACE_UK = 3
+    BRIGHTBOX = 4
 
 
 class State(object):
@@ -49,3 +50,14 @@ class State(object):
     RUNNING = 0
     PENDING = 1
     UNKNOWN = 2
+    ERROR = 3
+    DELETED = 4
+
+class MemberCondition(object):
+    """
+    Each member of a load balancer can have an associated condition 
+    which determines its role within the load balancer.
+    """
+    ENABLED = 0
+    DISABLED = 1
+    DRAINING = 2
