@@ -14,7 +14,8 @@
 # limitations under the License.
 import sys
 import unittest
-import httplib
+
+from libcloud.utils.py3 import httplib
 
 from libcloud.compute.drivers.ec2 import EC2NodeDriver, EC2APSENodeDriver
 from libcloud.compute.drivers.ec2 import NimbusNodeDriver, EucNodeDriver
@@ -65,7 +66,6 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
         self.assertEqual(node.extra['clienttoken'], token)
 
         # from: http://docs.amazonwebservices.com/AWSEC2/latest/DeveloperGuide/index.html?Run_Instance_Idempotency.html
-
         #    If you repeat the request with the same client token, but change
         #    another request parameter, Amazon EC2 returns an
         #    IdempotentParameterMismatch error.
@@ -79,7 +79,8 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
             self.driver.create_node(name='foo', image=image, size=size,
                     ex_mincount='2', ex_maxcount='2',
                     ex_clienttoken=token)
-        except IdempotentParamError, e:
+        except IdempotentParamError:
+            e = sys.exc_info()[1]
             idem_error = e
         self.assertTrue(idem_error is not None)
 
@@ -99,16 +100,33 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
 
     def test_list_nodes(self):
         node = self.driver.list_nodes()[0]
-        public_ips = sorted(node.public_ip)
+        public_ips = sorted(node.public_ips)
         self.assertEqual(node.id, 'i-4382922a')
         self.assertEqual(node.name, node.id)
-        self.assertEqual(len(node.public_ip), 2)
-        self.assertEqual(node.extra['launchdatetime'], '2009-08-07T05:47:04.000Z')
+        self.assertEqual(len(node.public_ips), 2)
+        self.assertEqual(node.extra['launchdatetime'],
+                            '2009-08-07T05:47:04.000Z')
         self.assertTrue('instancetype' in node.extra)
 
         self.assertEqual(public_ips[0], '1.2.3.4')
         self.assertEqual(public_ips[1], '1.2.3.5')
 
+        nodes = self.driver.list_nodes(ex_node_ids=['i-4382922a',
+                                                    'i-8474834a'])
+        ret_node1 = nodes[0]
+        ret_node2 = nodes[1]
+
+        self.assertEqual(ret_node1.id, 'i-4382922a')
+        self.assertEqual(ret_node2.id, 'i-8474834a')
+
+        self.assertEqual(ret_node1.extra['launchdatetime'],
+                                        '2009-08-07T05:47:04.000Z')
+        self.assertTrue('instancetype' in ret_node1.extra)
+
+        self.assertEqual(ret_node2.extra['launchdatetime'],
+                                        '2009-08-07T05:47:04.000Z')
+        self.assertTrue('instancetype' in ret_node2.extra)
+
     def test_list_nodes_with_name_tag(self):
         EC2MockHttp.type = 'WITH_TAGS'
         node = self.driver.list_nodes()[0]
@@ -125,6 +143,16 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
         ret = self.driver.reboot_node(node)
         self.assertTrue(ret)
 
+    def test_ex_start_node(self):
+        node = Node('i-4382922a', None, None, None, None, self.driver)
+        ret = self.driver.ex_start_node(node)
+        self.assertTrue(ret)
+
+    def test_ex_stop_node(self):
+        node = Node('i-4382922a', None, None, None, None, self.driver)
+        ret = self.driver.ex_stop_node(node)
+        self.assertTrue(ret)
+
     def test_destroy_node(self):
         node = Node('i-4382922a', None, None, None, None, self.driver)
         ret = self.driver.destroy_node(node)
@@ -156,9 +184,10 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
             self.assertTrue('m2.4xlarge' in ids)
 
             if region_name == 'us-east-1':
-                self.assertEqual(len(sizes), 11)
+                self.assertEqual(len(sizes), 12)
                 self.assertTrue('cg1.4xlarge' in ids)
                 self.assertTrue('cc1.4xlarge' in ids)
+                self.assertTrue('cc2.8xlarge' in ids)
             else:
                 self.assertEqual(len(sizes), 9)
 
@@ -168,7 +197,8 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
         images = self.driver.list_images()
         image = images[0]
         self.assertEqual(len(images), 1)
-        self.assertEqual(image.name, 'ec2-public-images/fedora-8-i386-base-v1.04.manifest.xml')
+        self.assertEqual(image.name,
+                    'ec2-public-images/fedora-8-i386-base-v1.04.manifest.xml')
         self.assertEqual(image.id, 'ami-be3adfd7')
 
     def test_ex_list_availability_zones(self):
@@ -227,6 +257,22 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
         self.assertTrue(node2.id in nodes_elastic_ips2)
         self.assertEqual(nodes_elastic_ips2[node2.id], [])
 
+    def test_ex_describe_all_addresses(self):
+        EC2MockHttp.type = 'all_addresses'
+        elastic_ips1 = self.driver.ex_describe_all_addresses()
+        elastic_ips2 = self.driver.ex_describe_all_addresses(only_allocated=True)
+
+        self.assertEqual(len(elastic_ips1), 3)
+        self.assertTrue('1.2.3.5' in elastic_ips1)
+
+        self.assertEqual(len(elastic_ips2), 2)
+        self.assertTrue('1.2.3.5' not in elastic_ips2)
+
+    def test_ex_associate_addresses(self):
+        node = Node('i-4382922a', None, None, None, None, self.driver)
+        ret = self.driver.ex_associate_addresses(node, '1.2.3.4')
+        self.assertTrue(ret)
+
     def test_ex_change_node_size_same_size(self):
         size = NodeSize('m1.small', 'Small Instance', None, None, None, None, driver=self.driver)
         node = Node('i-4382922a', None, None, None, None, self.driver,
@@ -268,6 +314,14 @@ class EC2MockHttp(MockHttp):
         body = self.fixtures.load('reboot_instances.xml')
         return (httplib.OK, body, {}, httplib.responses[httplib.OK])
 
+    def _StartInstances(self, method, url, body, headers):
+        body = self.fixtures.load('start_instances.xml')
+        return (httplib.OK, body, {}, httplib.responses[httplib.OK])
+
+    def _StopInstances(self, method, url, body, headers):
+        body = self.fixtures.load('stop_instances.xml')
+        return (httplib.OK, body, {}, httplib.responses[httplib.OK])
+
     def _DescribeImages(self, method, url, body, headers):
         body = self.fixtures.load('describe_images.xml')
         return (httplib.OK, body, {}, httplib.responses[httplib.OK])
@@ -304,6 +358,14 @@ class EC2MockHttp(MockHttp):
         body = self.fixtures.load('describe_addresses_multi.xml')
         return (httplib.OK, body, {}, httplib.responses[httplib.OK])
 
+    def _AssociateAddress(self, method, url, body, headers):
+        body = self.fixtures.load('associate_address.xml')
+        return (httplib.OK, body, {}, httplib.responses[httplib.OK])
+
+    def _all_addresses_DescribeAddresses(self, method, url, body, headers):
+        body = self.fixtures.load('describe_addresses_all.xml')
+        return (httplib.OK, body, {}, httplib.responses[httplib.OK])
+
     def _WITH_TAGS_DescribeAddresses(self, method, url, body, headers):
         body = self.fixtures.load('describe_addresses_multi.xml')
         return (httplib.OK, body, {}, httplib.responses[httplib.OK])
@@ -399,17 +461,17 @@ class NimbusTests(EC2Tests):
         # overridden from EC2Tests -- Nimbus doesn't support elastic IPs.
         node = self.driver.list_nodes()[0]
         self.assertExecutedMethodCount(0)
-        public_ips = node.public_ip
+        public_ips = node.public_ips
         self.assertEqual(node.id, 'i-4382922a')
-        self.assertEqual(len(node.public_ip), 1)
+        self.assertEqual(len(node.public_ips), 1)
         self.assertEqual(public_ips[0], '1.2.3.5')
         self.assertEqual(node.extra['tags'], {})
 
         node = self.driver.list_nodes()[1]
         self.assertExecutedMethodCount(0)
-        public_ips = node.public_ip
+        public_ips = node.public_ips
         self.assertEqual(node.id, 'i-8474834a')
-        self.assertEqual(len(node.public_ip), 1)
+        self.assertEqual(len(node.public_ips), 1)
         self.assertEqual(public_ips[0], '1.2.3.5')
         self.assertEqual(node.extra['tags'], {'user_key0': 'user_val0', 'user_key1': 'user_val1'})
 
