@@ -13,9 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
 import sys
-import httplib
 import unittest
 
 from libcloud.storage.drivers.google_storage import GoogleStorageDriver
